@@ -2,10 +2,10 @@
 #################################################################
 #  Copyright notice
 #
-#  (c) 2012 Jérôme Schneider <mail@jeromeschneider.fr>
+#  (c) 2013 Jérôme Schneider <mail@jeromeschneider.fr>
 #  All rights reserved
 #
-#  http://baikal.codr.fr
+#  http://baikal-server.com
 #
 #  This script is part of the Baïkal Server project. The Baïkal
 #  Server project is free software; you can redistribute it
@@ -101,7 +101,7 @@ HTML;
 			}
 		}
 
-		if(version_compare($sVersionFrom, '2.3.0', '<=')) {
+		if(version_compare($sVersionFrom, '0.2.3', '<=')) {
 			# Upgrading DB
 
 			#	etag VARCHAR(32),
@@ -129,7 +129,7 @@ HTML;
 					"ALTER TABLE calendarobjects ADD COLUMN firstoccurence integer",
 					"ALTER TABLE calendarobjects ADD COLUMN lastoccurence integer",
 					"ALTER TABLE calendars ADD COLUMN transparent bool",
-					"ALTER TABLE principals ADD COLUMN vcardurl VARCHAR(80)",	# This one is added in SQLite but not MySQL, because it is already there since the beginning in MySQL
+					"ALTER TABLE principals ADD COLUMN vcardurl text",	# This one is added in SQLite but not MySQL, because it is already there since the beginning in MySQL
 				);
 
 				$this->aSuccess[] = "SQLite database has been successfuly upgraded.'";
@@ -145,6 +145,10 @@ HTML;
 				return FALSE;
 			}
 		}
+
+		if(version_compare($sVersionFrom, '0.2.4', '<=')) {
+			# Nothing to do :)
+		}
 		
 		$this->updateConfiguredVersion($sVersionTo);
 		return TRUE;
